@@ -86,7 +86,7 @@ sub pull
 
     $self->prune();
 
-    system_ad("git pull");
+    system_ad("git pull -X theirs");
 
     return 1;
 }
@@ -148,6 +148,15 @@ sub commits_from
     return \@new_commits;
 }
 
+sub has
+{
+    my ($self, $id) = @_;
+
+    my $res = system("git show -s $id >/dev/null 2>&1");
+
+    return ($res == 0);
+}
+
 sub show
 {
     my ($self, $id) = @_;
